#[non_exhaustive]pub enum Request {
Destroy,
Enable,
Disable,
SetSurroundingText {
text: String,
cursor: i32,
anchor: i32,
},
SetTextChangeCause {
cause: WEnum<ChangeCause>,
},
SetContentType {
hint: WEnum<ContentHint>,
purpose: WEnum<ContentPurpose>,
},
SetCursorRectangle {
x: i32,
y: i32,
width: i32,
height: i32,
},
Commit,
SetAvailableActions {
available_actions: Vec<u8>,
},
ShowInputPanel,
HideInputPanel,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
Destroy the wp_text_input
Destroy the wp_text_input object. Also disables all surfaces enabled through this wp_text_input object.
This is a destructor, once received this object cannot be used any longer.
Enable
Request text input to be enabled
Requests text input on the surface previously obtained from the enter event.
This request must be issued every time the focused text input changes to a new one, including within the current surface. Use zwp_text_input_v3.disable when there is no longer any input focus on the current surface.
Clients must not enable more than one text input on the single seat and should disable the current text input before enabling the new one. Requests to enable a text input when another text input is enabled on the same seat must be ignored by compositor.
This request resets all state associated with previous enable, disable, set_surrounding_text, set_text_change_cause, set_content_type, and set_cursor_rectangle requests, as well as the state associated with preedit_string, commit_string, and delete_surrounding_text events.
The set_surrounding_text, set_content_type and set_cursor_rectangle requests must follow if the text input supports the necessary functionality.
State set with this request is double-buffered. It will get applied on the next zwp_text_input_v3.commit request, and stay valid until the next committed enable or disable request.
The changes must be applied by the compositor after issuing a zwp_text_input_v3.commit request.
Disable
Disable text input on a surface
Explicitly disable text input on the current surface (typically when there is no focus on any text entry inside the surface).
State set with this request is double-buffered. It will get applied on the next zwp_text_input_v3.commit request.
SetSurroundingText
sets the surrounding text
Sets the surrounding plain text around the input, excluding the preedit text.
The client should notify the compositor of any changes in any of the values carried with this request, including changes caused by handling incoming text-input events as well as changes caused by other mechanisms like keyboard typing.
If the client is unaware of the text around the cursor, it should not issue this request, to signify lack of support to the compositor.
Text is UTF-8 encoded, and should include the cursor position, the complete selection and additional characters before and after them. There is a maximum length of wayland messages, so text can not be longer than 4000 bytes.
Cursor is the byte offset of the cursor within text buffer.
Anchor is the byte offset of the selection anchor within text buffer. If there is no selected text, anchor is the same as cursor.
If any preedit text is present, it is replaced with a cursor for the purpose of this event.
Values set with this request are double-buffered. They will get applied on the next zwp_text_input_v3.commit request, and stay valid until the next committed enable or disable request.
The initial state for affected fields is empty, meaning that the text input does not support sending surrounding text. If the empty values get applied, subsequent attempts to change them may have no effect.
SetTextChangeCause
indicates the cause of surrounding text change
Tells the compositor why the text surrounding the cursor changed.
Whenever the client detects an external change in text, cursor, or anchor posision, it must issue this request to the compositor. This request is intended to give the input method a chance to update the preedit text in an appropriate way, e.g. by removing it when the user starts typing with a keyboard.
cause describes the source of the change.
The value set with this request is double-buffered. It must be applied and reset to initial at the next zwp_text_input_v3.commit request.
The initial value of cause is input_method.
Fields
cause: WEnum<ChangeCause>SetContentType
set content purpose and hint
Sets the content purpose and content hint. While the purpose is the basic purpose of an input field, the hint flags allow to modify some of the behavior.
Values set with this request are double-buffered. They will get applied on the next zwp_text_input_v3.commit request. Subsequent attempts to update them may have no effect. The values remain valid until the next committed enable or disable request.
The initial value for hint is none, and the initial value for purpose is normal.
SetCursorRectangle
set cursor position
Marks an area around the cursor as a x, y, width, height rectangle in surface local coordinates.
Allows the compositor to put a window with word suggestions near the cursor, without obstructing the text being input.
If the client is unaware of the position of edited text, it should not issue this request, to signify lack of support to the compositor.
Values set with this request are double-buffered. They will get applied on the next zwp_text_input_v3.commit request, and stay valid until the next committed enable or disable request.
The initial values describing a cursor rectangle are empty. That means the text input does not support describing the cursor area. If the empty values get applied, subsequent attempts to change them may have no effect.
As of version 2, the zwp_text_input_v3.commit request does not apply values sent with this request. Instead, it stores them in a separate “committed” area. The committed values, if still valid, get applied on the next wl_surface.commit request on the surface with text-input focus. Both committed and applied values get invalidated on:
- the next committed enable or disable request, or
- a change of the focused surface of the text-input (leave or enter events).
This double stage application allows the compositor to position the input method popup in the same frame as the contents of the text on the surface are updated.
Commit
commit state
Atomically applies state changes recently sent to the compositor.
The commit request establishes and updates the state of the client, and must be issued after any changes to apply them.
Text input state (enabled status, content purpose, content hint, surrounding text and change cause, cursor rectangle) is conceptually double-buffered within the context of a text input, i.e. between a committed enable request and the following committed enable or disable request.
Protocol requests modify the pending state, as opposed to the current state in use by the input method. A commit request atomically applies all pending state, replacing the current state. After commit, the new pending state is as documented for each related request.
Requests are applied in the order of arrival.
Neither current nor pending state are modified unless noted otherwise.
The compositor must count the number of commit requests coming from each zwp_text_input_v3 object and use the count as the serial in done events.
SetAvailableActions
set the available actions
Set the actions available for this text input.
Values set with this request are double-buffered. They will get applied on the next zwp_text_input_v3.commit request.
If the available_actions array contains the none action, or contains the same action multiple times, the compositor must raise the invalid_action protocol error.
Initially, no actions are available.
Only available since version 2 of the interface
ShowInputPanel
show input panel
Requests an input panel to be shown (e.g. a on-screen keyboard).
This request only hints the desired interaction pattern from the client side, and its effect may be ignored by compositors given other environmental factors. Repeated calls will be ignored.
Only available since version 2 of the interface
HideInputPanel
hide input panel
Requests an input panel to be hidden.
This request only hints the desired interaction pattern from the client side, and its effect may be ignored by compositors given other environmental factors. Repeated calls will be ignored.
Only available since version 2 of the interface
Implementations